
# Type: part of


holds between parts and wholes (material entities or processes)

URI: [biolink:part_of](https://w3id.org/biolink/vocab/part_of)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [overlaps](overlaps.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | BFO:0000050 |
|  | | SEMMEDDB:PART_OF |
|  | | WD:P361 |
| **In Subsets:** | | translator_minimal |

